@@ -6,57 +6,38 @@ pub(crate) mod rust {
     /// Rust-compatible list
     pub type List<T> = Vec<T>;
 
-    use super::TakeFirst;
-    impl<T: Clone> TakeFirst<T> for List<T> {
+    use super::ListAPI;
+    impl<T: Clone> ListAPI<T> for List<T> {
         fn take_first(self) -> T {
             self.into_iter()
                 .next()
                 .expect("expected at least 1 element")
         }
     }
-
-    #[cfg(test)]
-    mod tests {
-        use super::List as GenericList;
-        type List = GenericList<u8>;
-
-        #[test]
-        fn test_size() {
-            assert_eq!(std::mem::size_of::<List>(), 24);
-        }
-    }
 }
 
 #[cfg(feature = "compile-with-external-structures")]
 pub(crate) mod external {
-    use crate::containers::get_drop_fn::GetDropFn;
-
-    use crate::containers::size::LIST_SIZE;
-
-    #[repr(C)]
-    #[derive(Debug, Clone, Copy)]
-    pub struct ListBlob {
-        blob: [u8; LIST_SIZE],
-    }
+    use crate::blobs::ListBlob;
+    use crate::containers::get_drop_fn::GetDropListFn;
 
     /// C-compatible list
     #[repr(C)]
     pub struct List<T>
     where
-        T: GetDropFn,
+        T: GetDropListFn,
     {
-        blob: ListBlob,
-        _t: std::marker::PhantomData<T>,
+        pub(crate) blob: ListBlob,
+        pub(crate) _t: std::marker::PhantomData<T>,
     }
 
     impl<T> Drop for List<T>
     where
-        T: GetDropFn,
+        T: GetDropListFn,
     {
         fn drop(&mut self) {
-            let drop_item_in_place = T::get_drop_ptr_in_place_fn();
-            let drop_list_blob = T::get_drop_list_blob_fn();
-            unsafe { drop_list_blob(self.blob, drop_item_in_place) }
+            let drop_list_fn = T::get_drop_list_fn();
+            unsafe { drop_list_fn(&mut self.blob) }
         }
     }
 
@@ -84,20 +65,21 @@ pub(crate) mod external {
         }
     }
 
-    impl<T: GetDropFn> From<ListBlob> for List<T> {
-        fn from(blob: ListBlob) -> Self {
-            unsafe { std::mem::transmute(blob) }
-        }
-    }
+    impl<T: GetDropListFn> IntoIterator for List<T>
+    where
+        Vec<T>: From<List<T>>,
+    {
+        type Item = T;
+        type IntoIter = std::vec::IntoIter<T>;
 
-    impl<T: GetDropFn> From<List<T>> for ListBlob {
-        fn from(list: List<T>) -> Self {
-            unsafe { std::mem::transmute(list) }
+        fn into_iter(self) -> Self::IntoIter {
+            let v: Vec<T> = self.into();
+            v.into_iter()
         }
     }
 
     use super::ExternalSharedByteList;
-    use super::TakeFirst;
+    use super::ListAPI;
 
     macro_rules! gen_list_impl_for {
         (
@@ -105,91 +87,83 @@ pub(crate) mod external {
             $new:ident,
             $with_capacity:ident,
             $from_raw:ident,
-            $shrink_to_fit:ident,
             $push:ident,
             $remove:ident,
+            $shrink_to_fit:ident,
             $as_ptr:ident,
             $len:ident,
             $capacity:ident
         ) => {
-            use super::{List, ListBlob, TakeFirst};
-
-            #[repr(C)]
-            struct RemoveResult {
-                new_blob: ListBlob,
-                removed_item: $t,
-            }
+            use super::{List, ListAPI, ListBlob};
+            use crate::blobs::HasBlob;
 
             extern "C" {
                 fn $new() -> ListBlob;
                 fn $with_capacity(capacity: u64) -> ListBlob;
                 fn $from_raw(ptr: *mut $t, size: u64) -> ListBlob;
-                fn $shrink_to_fit(blob: ListBlob) -> ListBlob;
-                fn $push(blob: ListBlob, item: $t) -> ListBlob;
-                fn $remove(blob: ListBlob, index: u64) -> RemoveResult;
-                fn $as_ptr(blob: ListBlob) -> *mut $t;
-                fn $len(blob: ListBlob) -> u64;
-                fn $capacity(blob: ListBlob) -> u64;
+                fn $push(blob: *mut ListBlob, item: $t);
+                fn $remove(blob: *mut ListBlob, index: u64) -> $t;
+                fn $shrink_to_fit(blob: *mut ListBlob);
+                fn $as_ptr(blob: *mut ListBlob) -> *mut $t;
+                fn $len(blob: *const ListBlob) -> u64;
+                fn $capacity(blob: *const ListBlob) -> u64;
             }
 
             impl List<$t> {
                 /// Equivalent of Vec::new
                 pub fn new() -> Self {
                     let blob = unsafe { $new() };
-                    Self {
-                        blob,
-                        _t: std::marker::PhantomData,
-                    }
+                    Self::from_blob(blob)
                 }
 
                 /// Equivalent of Vec::with_capacity
                 pub fn with_capacity(capacity: usize) -> Self {
                     let blob = unsafe { $with_capacity(capacity as u64) };
-                    Self {
-                        blob,
-                        _t: std::marker::PhantomData,
-                    }
+                    Self::from_blob(blob)
                 }
 
                 pub(crate) fn from_raw(ptr: *mut $t, size: usize) -> Self {
                     let blob = unsafe { $from_raw(ptr, size as u64) };
-                    Self {
-                        blob,
-                        _t: std::marker::PhantomData,
-                    }
+                    Self::from_blob(blob)
                 }
 
                 pub(crate) fn shrink_to_fit(&mut self) {
-                    self.blob = unsafe { $shrink_to_fit(self.blob) };
+                    unsafe { $shrink_to_fit(&mut self.blob) };
                 }
 
                 /// Equivalent of Vec::push
                 pub fn push(&mut self, item: $t) {
-                    self.blob = unsafe { $push(self.blob, item) };
+                    unsafe { $push(&mut self.blob, item) };
                 }
 
                 /// Equivalent of Vec::rmeove
                 pub fn remove(&mut self, index: usize) -> $t {
-                    let RemoveResult {
-                        new_blob,
-                        removed_item,
-                    } = unsafe { $remove(self.blob, index as u64) };
-                    self.blob = new_blob;
-                    removed_item
+                    unsafe { $remove(&mut self.blob, index as u64) }
                 }
 
-                pub(crate) fn as_ptr(&self) -> *mut $t {
-                    unsafe { $as_ptr(self.blob) }
+                pub(crate) fn as_ptr(&self) -> *const $t {
+                    let blob_ptr: *const ListBlob = &self.blob;
+                    unsafe { $as_ptr(blob_ptr as *mut ListBlob) }
+                }
+
+                pub(crate) fn as_mut_ptr(&mut self) -> *mut $t {
+                    unsafe { $as_ptr(&mut self.blob) }
+                }
+
+                pub(crate) fn into_ptr(mut self) -> *mut $t {
+                    let ptr = self.as_mut_ptr();
+                    std::mem::forget(self);
+                    ptr
                 }
 
                 /// Equivalent of Vec::len
                 pub fn len(&self) -> usize {
-                    unsafe { $len(self.blob) as usize }
+                    unsafe { $len(&self.blob) as usize }
                 }
 
                 /// Equivalent of Vec::capacity
                 pub fn capacity(&self) -> usize {
-                    unsafe { $capacity(self.blob) as usize }
+                    unsafe { $capacity(&self.blob) as usize }
                 }
             }
 
@@ -244,9 +218,8 @@ pub(crate) mod external {
             impl From<List<$t>> for Vec<$t> {
                 fn from(mut list: List<$t>) -> Self {
                     list.shrink_to_fit();
-                    let ptr = list.as_ptr();
                     let len = list.len();
-                    list.blob = unsafe { $new() };
+                    let ptr = list.into_ptr();
                     unsafe { Vec::from_raw_parts(ptr, len, len) }
                 }
             }
@@ -261,7 +234,7 @@ pub(crate) mod external {
 
             impl std::ops::DerefMut for List<$t> {
                 fn deref_mut(&mut self) -> &mut Self::Target {
-                    unsafe { std::slice::from_raw_parts_mut(self.as_ptr(), self.len()) }
+                    unsafe { std::slice::from_raw_parts_mut(self.as_mut_ptr(), self.len()) }
                 }
             }
 
@@ -320,7 +293,7 @@ pub(crate) mod external {
                 }
             }
 
-            impl TakeFirst<$t> for List<$t> {
+            impl ListAPI<$t> for List<$t> {
                 fn take_first(self) -> $t {
                     if self.is_empty() {
                         panic!("can't get the first item from an empty list")
@@ -332,29 +305,26 @@ pub(crate) mod external {
 
             #[cfg(test)]
             mod tests {
-                use super::{make_one, List as GenericList, TakeFirst};
+                use super::{new_item, List as GenericList, ListAPI};
                 use std::ops::{Deref, DerefMut};
                 type List = GenericList<$t>;
 
-                #[test]
-                fn test_size() {
-                    assert_eq!(std::mem::size_of::<List>(), 24);
-                }
-
                 #[test]
                 fn test_new() {
-                    let _ = List::new();
+                    let list = List::new();
+                    drop(list);
                 }
 
                 #[test]
                 fn test_with_capacity() {
-                    let _ = List::with_capacity(10);
+                    let list = List::with_capacity(10);
+                    drop(list);
                 }
 
                 fn list_with_items(n: usize) -> List {
                     let mut list = List::new();
                     for _ in 0..n {
-                        list.push(make_one());
+                        list.push(new_item());
                     }
                     list
                 }
@@ -362,7 +332,7 @@ pub(crate) mod external {
                 fn vec_with_items(n: usize) -> Vec<$t> {
                     let mut list = vec![];
                     for _ in 0..n {
-                        list.push(make_one());
+                        list.push(new_item());
                     }
                     list
                 }
@@ -381,17 +351,17 @@ pub(crate) mod external {
                 #[test]
                 fn test_push() {
                     let mut list = List::with_capacity(10);
-                    list.push(make_one());
+                    list.push(new_item());
                 }
 
                 #[test]
                 fn test_remove() {
                     let mut list = list_with_items(10);
 
-                    assert_eq!(list.remove(0), make_one());
+                    assert_eq!(list.remove(0), new_item());
                     assert_eq!(list.len(), 9);
 
-                    assert_eq!(list.remove(3), make_one());
+                    assert_eq!(list.remove(3), new_item());
                     assert_eq!(list.len(), 8);
                 }
 
@@ -400,8 +370,8 @@ pub(crate) mod external {
                     let mut list = List::new();
                     assert_eq!(list.as_ptr(), std::ptr::null_mut());
 
-                    list.push(make_one());
-                    assert_eq!(unsafe { &*list.as_ptr() }, &make_one());
+                    list.push(new_item());
+                    assert_eq!(unsafe { &*list.as_ptr() }, &new_item());
                 }
 
                 #[test]
@@ -446,8 +416,8 @@ pub(crate) mod external {
                     let mut list = List::new();
                     // assert_eq!(list.clone().len(), 0);
 
-                    list.push(make_one());
-                    list.push(make_one());
+                    list.push(new_item());
+                    list.push(new_item());
                     let copy = list.clone();
                     assert_eq!(copy.len(), 2);
                     drop(copy);
@@ -467,8 +437,8 @@ pub(crate) mod external {
                     let mut vec = vec![];
                     assert_eq!(list.deref(), &vec);
 
-                    list.push(make_one());
-                    vec.push(make_one());
+                    list.push(new_item());
+                    vec.push(new_item());
                     assert_eq!(list.deref(), &vec);
                 }
 
@@ -478,17 +448,17 @@ pub(crate) mod external {
                     let mut vec = vec![];
                     assert_eq!(list.deref_mut(), &vec);
 
-                    list.push(make_one());
-                    vec.push(make_one());
+                    list.push(new_item());
+                    vec.push(new_item());
                     assert_eq!(list.deref_mut(), &vec);
                 }
 
                 #[test]
                 fn test_fmt() {
                     let mut list = List::new();
-                    list.push(make_one());
+                    list.push(new_item());
 
-                    let vec = vec![make_one()];
+                    let vec = vec![new_item()];
                     let slice = &vec;
                     assert_eq!(format!("{:?}", list), format!("{:?}", slice));
                 }
@@ -515,17 +485,17 @@ pub(crate) mod external {
                 #[test]
                 fn test_index() {
                     let mut list = List::new();
-                    list.push(make_one());
+                    list.push(new_item());
 
-                    assert_eq!(list[0], make_one());
+                    assert_eq!(list[0], new_item());
                 }
 
                 #[test]
                 fn test_take_first() {
                     let mut list = List::new();
-                    list.push(make_one());
+                    list.push(new_item());
 
-                    assert_eq!(list.take_first(), make_one());
+                    assert_eq!(list.take_first(), new_item());
                 }
 
                 #[test]
@@ -538,99 +508,94 @@ pub(crate) mod external {
 
     mod of_nodes {
         #[cfg(test)]
-        fn make_one() -> crate::Node {
-            crate::Node::True(crate::nodes::True {
-                expression_l: crate::Loc::default(),
-            })
+        fn new_item() -> crate::Node {
+            crate::Node::new_true(crate::Loc::default())
         }
 
         gen_list_impl_for!(
             crate::Node,
-            lib_ruby_parser_containers_node_list_blob_new,
-            lib_ruby_parser_containers_node_list_blob_with_capacity,
-            lib_ruby_parser_containers_node_list_blob_from_raw,
-            lib_ruby_parser_containers_node_list_blob_shrink_to_fit,
-            lib_ruby_parser_containers_node_list_blob_push,
-            lib_ruby_parser_containers_node_list_blob_remove,
-            lib_ruby_parser_containers_node_list_blob_as_ptr,
-            lib_ruby_parser_containers_node_list_blob_len,
-            lib_ruby_parser_containers_node_list_blob_capacity
+            lib_ruby_parser__external__list__of_nodes__new,
+            lib_ruby_parser__external__list__of_nodes__with_capacity,
+            lib_ruby_parser__external__list__of_nodes__from_raw,
+            lib_ruby_parser__external__list__of_nodes__push,
+            lib_ruby_parser__external__list__of_nodes__remove,
+            lib_ruby_parser__external__list__of_nodes__shrink_to_fit,
+            lib_ruby_parser__external__list__of_nodes__as_ptr,
+            lib_ruby_parser__external__list__of_nodes__get_len,
+            lib_ruby_parser__external__list__of_nodes__get_capacity
         );
     }
     mod of_diagnostics {
         #[cfg(test)]
-        fn make_one() -> crate::Diagnostic {
-            crate::Diagnostic {
-                level: crate::ErrorLevel::Warning,
-                message: crate::DiagnosticMessage::AliasNthRef,
-                loc: crate::Loc::default(),
-            }
+        fn new_item() -> crate::Diagnostic {
+            crate::Diagnostic::new(
+                crate::ErrorLevel::warning(),
+                crate::DiagnosticMessage::new_alias_nth_ref(),
+                crate::Loc::default(),
+            )
         }
 
         gen_list_impl_for!(
             crate::Diagnostic,
-            lib_ruby_parser_containers_diagnostic_list_blob_new,
-            lib_ruby_parser_containers_diagnostic_list_blob_with_capacity,
-            lib_ruby_parser_containers_diagnostic_list_blob_from_raw,
-            lib_ruby_parser_containers_diagnostic_list_blob_shrink_to_fit,
-            lib_ruby_parser_containers_diagnostic_list_blob_push,
-            lib_ruby_parser_containers_diagnostic_list_blob_remove,
-            lib_ruby_parser_containers_diagnostic_list_blob_as_ptr,
-            lib_ruby_parser_containers_diagnostic_list_blob_len,
-            lib_ruby_parser_containers_diagnostic_list_blob_capacity
+            lib_ruby_parser__external__list__of_diagnostics__new,
+            lib_ruby_parser__external__list__of_diagnostics__with_capacity,
+            lib_ruby_parser__external__list__of_diagnostics__from_raw,
+            lib_ruby_parser__external__list__of_diagnostics__push,
+            lib_ruby_parser__external__list__of_diagnostics__remove,
+            lib_ruby_parser__external__list__of_diagnostics__shrink_to_fit,
+            lib_ruby_parser__external__list__of_diagnostics__as_ptr,
+            lib_ruby_parser__external__list__of_diagnostics__get_len,
+            lib_ruby_parser__external__list__of_diagnostics__get_capacity
         );
     }
     mod of_comments {
         #[cfg(test)]
-        fn make_one() -> crate::source::Comment {
-            crate::source::Comment {
-                location: crate::Loc::default(),
-                kind: crate::source::CommentType::Inline,
-            }
+        fn new_item() -> crate::source::Comment {
+            crate::source::Comment::make(
+                crate::Loc::new(1, 2),
+                crate::source::CommentType::unknown(),
+            )
         }
 
         gen_list_impl_for!(
             crate::source::Comment,
-            lib_ruby_parser_containers_comment_list_blob_new,
-            lib_ruby_parser_containers_comment_list_blob_with_capacity,
-            lib_ruby_parser_containers_comment_list_blob_from_raw,
-            lib_ruby_parser_containers_comment_list_blob_shrink_to_fit,
-            lib_ruby_parser_containers_comment_list_blob_push,
-            lib_ruby_parser_containers_comment_list_blob_remove,
-            lib_ruby_parser_containers_comment_list_blob_as_ptr,
-            lib_ruby_parser_containers_comment_list_blob_len,
-            lib_ruby_parser_containers_comment_list_blob_capacity
+            lib_ruby_parser__external__list__of_comments__new,
+            lib_ruby_parser__external__list__of_comments__with_capacity,
+            lib_ruby_parser__external__list__of_comments__from_raw,
+            lib_ruby_parser__external__list__of_comments__push,
+            lib_ruby_parser__external__list__of_comments__remove,
+            lib_ruby_parser__external__list__of_comments__shrink_to_fit,
+            lib_ruby_parser__external__list__of_comments__as_ptr,
+            lib_ruby_parser__external__list__of_comments__get_len,
+            lib_ruby_parser__external__list__of_comments__get_capacity
         );
     }
     mod of_magic_comments {
         #[cfg(test)]
-        fn make_one() -> crate::source::MagicComment {
-            crate::source::MagicComment {
-                kind: crate::source::MagicCommentKind::Encoding,
-                key_l: crate::Loc::default(),
-                value_l: crate::Loc::default(),
-            }
+        fn new_item() -> crate::source::MagicComment {
+            crate::source::MagicComment::new(
+                crate::source::MagicCommentKind::encoding(),
+                crate::Loc::default(),
+                crate::Loc::default(),
+            )
         }
 
         gen_list_impl_for!(
             crate::source::MagicComment,
-            lib_ruby_parser_containers_magic_comment_list_blob_new,
-            lib_ruby_parser_containers_magic_comment_list_blob_with_capacity,
-            lib_ruby_parser_containers_magic_comment_list_blob_from_raw,
-            lib_ruby_parser_containers_magic_comment_list_blob_shrink_to_fit,
-            lib_ruby_parser_containers_magic_comment_list_blob_push,
-            lib_ruby_parser_containers_magic_comment_list_blob_remove,
-            lib_ruby_parser_containers_magic_comment_list_blob_as_ptr,
-            lib_ruby_parser_containers_magic_comment_list_blob_len,
-            lib_ruby_parser_containers_magic_comment_list_blob_capacity
+            lib_ruby_parser__external__list__of_magic_comments__new,
+            lib_ruby_parser__external__list__of_magic_comments__with_capacity,
+            lib_ruby_parser__external__list__of_magic_comments__from_raw,
+            lib_ruby_parser__external__list__of_magic_comments__push,
+            lib_ruby_parser__external__list__of_magic_comments__remove,
+            lib_ruby_parser__external__list__of_magic_comments__shrink_to_fit,
+            lib_ruby_parser__external__list__of_magic_comments__as_ptr,
+            lib_ruby_parser__external__list__of_magic_comments__get_len,
+            lib_ruby_parser__external__list__of_magic_comments__get_capacity
         );
     }
     mod of_tokens {
         #[cfg(test)]
-        fn make_one() -> crate::Token {
-            use crate::TokenTrait;
-
-            use crate::bytes::BytesTrait;
+        fn new_item() -> crate::Token {
             crate::Token::new(
                 crate::Lexer::tINTEGER,
                 crate::Bytes::empty(),
@@ -642,55 +607,53 @@ pub(crate) mod external {
 
         gen_list_impl_for!(
             crate::Token,
-            lib_ruby_parser_containers_token_list_blob_new,
-            lib_ruby_parser_containers_token_list_blob_with_capacity,
-            lib_ruby_parser_containers_token_list_blob_from_raw,
-            lib_ruby_parser_containers_token_list_blob_shrink_to_fit,
-            lib_ruby_parser_containers_token_list_blob_push,
-            lib_ruby_parser_containers_token_list_blob_remove,
-            lib_ruby_parser_containers_token_list_blob_as_ptr,
-            lib_ruby_parser_containers_token_list_blob_len,
-            lib_ruby_parser_containers_token_list_blob_capacity
+            lib_ruby_parser__external__list__of_tokens__new,
+            lib_ruby_parser__external__list__of_tokens__with_capacity,
+            lib_ruby_parser__external__list__of_tokens__from_raw,
+            lib_ruby_parser__external__list__of_tokens__push,
+            lib_ruby_parser__external__list__of_tokens__remove,
+            lib_ruby_parser__external__list__of_tokens__shrink_to_fit,
+            lib_ruby_parser__external__list__of_tokens__as_ptr,
+            lib_ruby_parser__external__list__of_tokens__get_len,
+            lib_ruby_parser__external__list__of_tokens__get_capacity
         );
     }
     mod of_source_lines {
         #[cfg(test)]
-        fn make_one() -> crate::source::SourceLine {
-            use crate::source::SourceLineTrait;
-
+        fn new_item() -> crate::source::SourceLine {
             crate::source::SourceLine::new(1, 2, false)
         }
 
         gen_list_impl_for!(
             crate::source::SourceLine,
-            lib_ruby_parser_containers_source_line_list_blob_new,
-            lib_ruby_parser_containers_source_line_list_blob_with_capacity,
-            lib_ruby_parser_containers_source_line_list_blob_from_raw,
-            lib_ruby_parser_containers_source_line_list_blob_shrink_to_fit,
-            lib_ruby_parser_containers_source_line_list_blob_push,
-            lib_ruby_parser_containers_source_line_list_blob_remove,
-            lib_ruby_parser_containers_source_line_list_blob_as_ptr,
-            lib_ruby_parser_containers_source_line_list_blob_len,
-            lib_ruby_parser_containers_source_line_list_blob_capacity
+            lib_ruby_parser__external__list__of_source_lines__new,
+            lib_ruby_parser__external__list__of_source_lines__with_capacity,
+            lib_ruby_parser__external__list__of_source_lines__from_raw,
+            lib_ruby_parser__external__list__of_source_lines__push,
+            lib_ruby_parser__external__list__of_source_lines__remove,
+            lib_ruby_parser__external__list__of_source_lines__shrink_to_fit,
+            lib_ruby_parser__external__list__of_source_lines__as_ptr,
+            lib_ruby_parser__external__list__of_source_lines__get_len,
+            lib_ruby_parser__external__list__of_source_lines__get_capacity
         );
     }
     mod of_u8 {
         #[cfg(test)]
-        fn make_one() -> u8 {
+        fn new_item() -> u8 {
             42
         }
 
         gen_list_impl_for!(
             u8,
-            lib_ruby_parser_containers_byte_list_blob_new,
-            lib_ruby_parser_containers_byte_list_blob_with_capacity,
-            lib_ruby_parser_containers_byte_list_blob_from_raw,
-            lib_ruby_parser_containers_byte_list_blob_shrink_to_fit,
-            lib_ruby_parser_containers_byte_list_blob_push,
-            lib_ruby_parser_containers_byte_list_blob_remove,
-            lib_ruby_parser_containers_byte_list_blob_as_ptr,
-            lib_ruby_parser_containers_byte_list_blob_len,
-            lib_ruby_parser_containers_byte_list_blob_capacity
+            lib_ruby_parser__external__list__of_bytes__new,
+            lib_ruby_parser__external__list__of_bytes__with_capacity,
+            lib_ruby_parser__external__list__of_bytes__from_raw,
+            lib_ruby_parser__external__list__of_bytes__push,
+            lib_ruby_parser__external__list__of_bytes__remove,
+            lib_ruby_parser__external__list__of_bytes__shrink_to_fit,
+            lib_ruby_parser__external__list__of_bytes__as_ptr,
+            lib_ruby_parser__external__list__of_bytes__get_len,
+            lib_ruby_parser__external__list__of_bytes__get_capacity
         );
 
         use super::ExternalSharedByteList;
@@ -702,18 +665,8 @@ pub(crate) mod external {
             }
         }
     }
-
-    #[cfg(test)]
-    mod tests {
-        use super::ListBlob;
-
-        #[test]
-        fn test_size() {
-            assert_eq!(std::mem::size_of::<ListBlob>(), 24);
-        }
-    }
 }
 
-pub(crate) trait TakeFirst<T: Clone> {
+pub(crate) trait ListAPI<T: Clone> {
     fn take_first(self) -> T;
 }
