@@ -8,10 +8,8 @@ pub(crate) mod string_ptr;
 
 pub(crate) mod helpers {
     pub(crate) use super::{
-        list::TakeFirst as ListTakeFirst,
-        maybe_ptr::{MaybePtrNone, MaybePtrSome},
-        maybe_string_ptr::{MaybeStringPtrNone, MaybeStringPtrSome},
-        ptr::UnPtr,
+        list::ListAPI, maybe_loc::MaybeLocAPI, maybe_ptr::MaybePtrAPI,
+        maybe_string_ptr::MaybeStringPtrAPI, ptr::PtrAPI,
     };
 }
 
@@ -34,3 +32,6 @@ pub use ptr::external::Ptr as ExternalPtr;
 pub use shared_byte_list::external::SharedByteList as ExternalSharedByteList;
 #[cfg(feature = "compile-with-external-structures")]
 pub use string_ptr::external::StringPtr as ExternalStringPtr;
+
+mod use_native_or_external;
+pub(crate) use use_native_or_external::use_native_or_external;
