@@ -1,44 +1,24 @@
-use crate::containers::helpers::UnPtr;
+crate::use_native_or_external!(Ptr);
+crate::use_native_or_external!(StringPtr);
+crate::use_native_or_external!(List);
 
-#[cfg(feature = "compile-with-external-structures")]
-use crate::containers::ExternalList;
-#[cfg(feature = "compile-with-external-structures")]
-type List<T> = ExternalList<T>;
-#[cfg(not(feature = "compile-with-external-structures"))]
-type List<T> = Vec<T>;
-
-#[cfg(feature = "compile-with-external-structures")]
-use crate::containers::ExternalPtr;
-#[cfg(feature = "compile-with-external-structures")]
-type Ptr<T> = ExternalPtr<T>;
-#[cfg(not(feature = "compile-with-external-structures"))]
-type Ptr<T> = Box<T>;
-
-#[cfg(feature = "compile-with-external-structures")]
-use crate::containers::ExternalStringPtr;
-#[cfg(feature = "compile-with-external-structures")]
-type StringPtr = ExternalStringPtr;
-#[cfg(not(feature = "compile-with-external-structures"))]
-type StringPtr = String;
-
-use crate::bytes::BytesTrait;
 use crate::debug_level;
 use crate::lexer::*;
 use crate::maybe_byte::*;
 use crate::source::buffer::*;
 use crate::source::Comment;
-use crate::source::CustomDecoder;
 use crate::source::MagicComment;
+use crate::source::MaybeDecoder;
 use crate::str_term::{str_types::*, HeredocEnd, StrTerm, StringLiteral};
 use crate::Context;
 use crate::Loc;
 use crate::StackState;
 use crate::StaticEnvironment;
+use crate::Token;
 use crate::TokenBuf;
 use crate::{error::Diagnostics, Bytes};
 use crate::{lex_states::*, LexState};
 use crate::{Diagnostic, DiagnosticMessage, ErrorLevel};
-use crate::{Token, TokenTrait};
 
 /// A struct responsible for converting a given input
 /// into a sequence of tokens
@@ -117,7 +97,7 @@ impl Lexer {
     pub(crate) const VTAB_CHAR: u8 = 0x0b;
 
     /// Constructs an instance of Lexer
-    pub fn new<Bytes, Name>(bytes: Bytes, name: Name, decoder: CustomDecoder) -> Self
+    pub fn new<Bytes, Name>(bytes: Bytes, name: Name, decoder: MaybeDecoder) -> Self
     where
         Bytes: Into<List<u8>>,
         Name: Into<StringPtr>,
@@ -257,7 +237,10 @@ impl Lexer {
                 Some(b'\r') => {
                     if !self.buffer.cr_seen {
                         self.buffer.cr_seen = true;
-                        self.warn(DiagnosticMessage::SlashRAtMiddleOfLine, self.current_loc());
+                        self.warn(
+                            DiagnosticMessage::new_slash_r_at_middle_of_line(),
+                            self.current_loc(),
+                        );
                     }
                 }
 
@@ -356,7 +339,7 @@ impl Lexer {
                         self.buffer.pushback(&c);
                         if self.lex_state.is_spacearg(&c, space_seen) {
                             self.warn(
-                                DiagnosticMessage::DStarInterpretedAsArgPrefix,
+                                DiagnosticMessage::new_d_star_interpreted_as_arg_prefix(),
                                 self.current_loc(),
                             );
                             result = Self::tDSTAR;
@@ -381,7 +364,7 @@ impl Lexer {
                         self.buffer.pushback(&c);
                         if self.lex_state.is_spacearg(&c, space_seen) {
                             self.warn(
-                                DiagnosticMessage::StarInterpretedAsArgPrefix,
+                                DiagnosticMessage::new_star_interpreted_as_arg_prefix(),
                                 self.current_loc(),
                             );
                             result = Self::tSTAR;
@@ -438,7 +421,7 @@ impl Lexer {
                                 c = self.nextc();
                                 if c.is_eof() {
                                     self.compile_error(
-                                        DiagnosticMessage::EmbeddedDocumentMeetsEof,
+                                        DiagnosticMessage::new_embedded_document_meets_eof(),
                                         begin_loc,
                                     );
                                     return Self::END_OF_INPUT;
@@ -636,7 +619,7 @@ impl Lexer {
                                     .is_identchar(self.buffer.pcur + 1, self.buffer.pend))
                         {
                             self.warn(
-                                DiagnosticMessage::AmpersandInterpretedAsArgPrefix,
+                                DiagnosticMessage::new_ampersand_interpreted_as_arg_prefix(),
                                 self.current_loc(),
                             );
                         }
@@ -780,7 +763,10 @@ impl Lexer {
                         c = self.nextc();
                         if c == b'.' {
                             if self.paren_nest == 0 && self.buffer.is_looking_at_eol() {
-                                self.warn(DiagnosticMessage::TripleDotAtEol, self.current_loc());
+                                self.warn(
+                                    DiagnosticMessage::new_triple_dot_at_eol(),
+                                    self.current_loc(),
+                                );
                             } else if self.lpar_beg >= 0
                                 && self.lpar_beg + 1 == self.paren_nest
                                 && last_state.is_some(EXPR_LABEL)
@@ -801,9 +787,9 @@ impl Lexer {
                         };
                         self.parse_numeric(b'.');
                         if prev.is_digit() {
-                            self.yyerror0(DiagnosticMessage::FractionAfterNumeric);
+                            self.yyerror0(DiagnosticMessage::new_fraction_after_numeric());
                         } else {
-                            self.yyerror0(DiagnosticMessage::NoDigitsAfterDot);
+                            self.yyerror0(DiagnosticMessage::new_no_digits_after_dot());
                         }
                         self.lex_state.set(EXPR_END);
                         self.buffer.set_ptok(self.buffer.pcur);
@@ -979,7 +965,7 @@ impl Lexer {
                         result = Self::tLPAREN_ARG;
                     } else if self.lex_state.is_some(EXPR_ENDFN) && !self.is_lambda_beginning() {
                         self.warn(
-                            DiagnosticMessage::ParenthesesIterpretedAsArglist,
+                            DiagnosticMessage::new_parentheses_iterpreted_as_arglist(),
                             self.current_loc(),
                         );
                     }
@@ -1099,7 +1085,7 @@ impl Lexer {
                 Some(c) => {
                     if !self.is_identchar() {
                         self.compile_error(
-                            DiagnosticMessage::InvalidChar { c },
+                            DiagnosticMessage::new_invalid_char(c),
                             self.current_loc(),
                         );
                         self.token_flush();
@@ -1126,7 +1112,7 @@ impl Lexer {
         if self.debug {
             println!("WARNING: {}", message.render())
         }
-        let diagnostic = Diagnostic::new(ErrorLevel::Warning, message, loc);
+        let diagnostic = Diagnostic::new(ErrorLevel::warning(), message, loc);
         self.diagnostics.emit(diagnostic);
     }
 
@@ -1143,10 +1129,7 @@ impl Lexer {
             && space_seen & !c.is_space()
         {
             self.warn(
-                DiagnosticMessage::AmbiguousOperator {
-                    operator: op.into(),
-                    interpreted_as: syn.into(),
-                },
+                DiagnosticMessage::new_ambiguous_operator(op.into(), syn.into()),
                 self.current_loc(),
             );
         }
@@ -1157,7 +1140,7 @@ impl Lexer {
         if self.debug {
             println!("Compile error: {}", message.render())
         }
-        let diagnostic = Diagnostic::new(ErrorLevel::Error, message, loc);
+        let diagnostic = Diagnostic::new(ErrorLevel::error(), message, loc);
         self.diagnostics.emit(diagnostic);
     }
 
@@ -1187,12 +1170,9 @@ impl Lexer {
 
     pub(crate) fn arg_ambiguous(&mut self, c: u8, loc: Loc) -> bool {
         if c == b'/' {
-            self.warn(DiagnosticMessage::AmbiguousRegexp, loc);
+            self.warn(DiagnosticMessage::new_ambiguous_regexp(), loc);
         } else {
-            self.warn(
-                DiagnosticMessage::AmbiguousFirstArgument { operator: c },
-                loc,
-            );
+            self.warn(DiagnosticMessage::new_ambiguous_first_argument(c), loc);
         }
         true
     }
@@ -1213,7 +1193,7 @@ impl Lexer {
         if self.debug {
             println!("yyerror0: {}", message.render())
         }
-        let diagnostic = Diagnostic::new(ErrorLevel::Error, message, loc);
+        let diagnostic = Diagnostic::new(ErrorLevel::error(), message, loc);
         self.diagnostics.emit(diagnostic);
     }
 
@@ -1289,7 +1269,7 @@ impl Lexer {
     pub(crate) fn multibyte_char_len(&mut self, ptr: usize) -> Option<usize> {
         let result = self._multibyte_char_len(ptr);
         if result.is_none() {
-            self.yyerror0(DiagnosticMessage::InvalidMultibyteChar);
+            self.yyerror0(DiagnosticMessage::new_invalid_multibyte_char());
         }
         result
     }
