@@ -137,14 +137,14 @@ impl ParseString for Lexer {
             self.literal_flush(self.buffer.pcur);
             if (func & STR_FUNC_QWORDS) != 0 {
                 /* no content to add, bailing out here */
-                self.yyerror0(DiagnosticMessage::UnterminatedList);
+                self.yyerror0(DiagnosticMessage::new_unterminated_list());
                 self.strterm = None;
                 return Self::tSTRING_END;
             }
             if (func & STR_FUNC_REGEXP) != 0 {
-                self.yyerror0(DiagnosticMessage::UnterminatedRegexp);
+                self.yyerror0(DiagnosticMessage::new_unterminated_regexp());
             } else {
-                self.yyerror0(DiagnosticMessage::UnterminatedString);
+                self.yyerror0(DiagnosticMessage::new_unterminated_string());
             }
             quote.func |= STR_FUNC_TERM;
         }
@@ -202,14 +202,13 @@ impl ParseString for Lexer {
         if self.toklen() > 0 {
             self.tokfix();
             self.compile_error(
-                DiagnosticMessage::UnknownRegexOptions {
-                    options: self
-                        .tokenbuf
+                DiagnosticMessage::new_unknown_regex_options(
+                    self.tokenbuf
                         .borrow_string()
                         .expect("expected buffer to have only utf-8 chars")
                         .to_string()
                         .into(),
-                },
+                ),
                 self.current_loc(),
             );
         }
@@ -397,7 +396,7 @@ impl ParseString for Lexer {
     fn tokadd_utf8_unterminated(&mut self) {
         self.token_flush();
         self.yyerror1(
-            DiagnosticMessage::UnterminatedUnicodeEscape,
+            DiagnosticMessage::new_unterminated_unicode_escape(),
             self.loc(self.buffer.ptok, self.buffer.pcur + 1),
         );
     }
@@ -480,17 +479,17 @@ impl ParseString for Lexer {
             numlen < 4
         } {
             self.yyerror1(
-                DiagnosticMessage::InvalidUnicodeEscape,
+                DiagnosticMessage::new_invalid_unicode_escape(),
                 self.loc(self.buffer.pcur, self.buffer.pcur + 1),
             );
             return wide && numlen > 0;
         }
         if codepoint > 0x10ffff {
-            self.yyerror0(DiagnosticMessage::TooLargeUnicodeCodepoint);
+            self.yyerror0(DiagnosticMessage::new_too_large_unicode_codepoint());
             return wide;
         }
         if (codepoint & 0xfffff800) == 0xd800 {
-            self.yyerror0(DiagnosticMessage::InvalidUnicodeCodepoint);
+            self.yyerror0(DiagnosticMessage::new_invalid_unicode_codepoint());
             return wide;
         }
         if regexp_literal != 0 {
@@ -572,7 +571,7 @@ impl ParseString for Lexer {
                     self.buffer.pcur = second;
                     self.token_flush();
                     self.buffer.pcur = pcur;
-                    self.yyerror0(DiagnosticMessage::MultipleCodepointAtSingleChar);
+                    self.yyerror0(DiagnosticMessage::new_multiple_codepoint_at_single_char());
                     self.token_flush();
                 }
             }
@@ -604,7 +603,7 @@ impl ParseString for Lexer {
     }
 
     fn tokadd_escape_eof(&mut self) -> Result<(), ()> {
-        self.yyerror0(DiagnosticMessage::InvalidEscapeCharacter);
+        self.yyerror0(DiagnosticMessage::new_invalid_escape_character());
         self.token_flush();
         Err(())
     }
@@ -713,7 +712,7 @@ impl ParseString for Lexer {
     }
 
     fn read_escape_eof(&mut self) -> MaybeByte {
-        self.yyerror0(DiagnosticMessage::InvalidEscapeCharacter);
+        self.yyerror0(DiagnosticMessage::new_invalid_escape_character());
         self.token_flush();
         MaybeByte::new(0)
     }
@@ -723,7 +722,10 @@ impl ParseString for Lexer {
 
         c = self.scan_hex(self.buffer.pcur, 2, numlen);
         if *numlen == 0 {
-            self.yyerror1(DiagnosticMessage::InvalidHexEscape, self.current_loc());
+            self.yyerror1(
+                DiagnosticMessage::new_invalid_hex_escape(),
+                self.current_loc(),
+            );
             self.token_flush();
             return MaybeByte::new(0);
         }
@@ -847,9 +849,7 @@ impl ParseString for Lexer {
 
     fn warn_space_char(&mut self, c: u8, prefix: &'static str) {
         self.warn(
-            DiagnosticMessage::InvalidCharacterSyntax {
-                suggestion: format!("{}\\{}", prefix, c).into(),
-            },
+            DiagnosticMessage::new_invalid_character_syntax(format!("{}\\{}", prefix, c).into()),
             self.current_loc(),
         )
     }
